use std::fs;

use image::imageops;
use image::GrayAlphaImage;

enum State {
    Header,
    Lsb,
    Msb(u8),
}

fn main() {
    let mut state = State::Header;
    let mut data = Vec::with_capacity(1100 * 1200 * 2);

    for b in fs::read("input").unwrap() {
        match state {
            State::Header if b == 3 => {
                state = State::Lsb;
            }
            State::Header => (),
            State::Lsb => {
                state = State::Msb(b);
            }
            State::Msb(lsb) => {
                let v = u16::from_le_bytes([lsb, b]);

                if v == 0x29c4 {
                    data.push(0);
                    data.push(255);
                } else {
                    data.push(if v > 0 { 255 } else { 127 });
                    data.push(255);
                }

                state = State::Lsb;
            }
        };
    }

    let mut img = GrayAlphaImage::from_raw(1100, 1200, data).unwrap();
    imageops::flip_vertical_in_place(&mut img);
    img.save("rv.png").unwrap();
}
